Universal Quality Index (UQI)
=============================

.. automodule:: viqa.fr_metrics.uqi
    :exclude-members: UQI


.. rubric:: Classes

.. currentmodule:: viqa.fr_metrics.uqi

.. autosummary::
    :toctree: generated/
    :template: class.rst

    UQI